import QtQuick 2.4

ModalDialog {
    id: root

    property string prompt:
        "<b><font color='#cc3333'>NOTICE:</font> By pressing Accept below, the owner of this equipment acknowledges being made aware of their responsibilities when enabling access to the Internet.
</b>
<h2>Internet Service</h2>
<p>The owner of this equipment and the facility in which it is installed is responsible for providing Internet service to this machine.
This machine may receive network service by either WiFi or wired Ethernet connectivity.
Performance of connectivity can vary greatly with the ISP and equipment (routers, switches, network load, etc.) used to provide access.
The owner of this equipment and the facility in which it is installed is responsible for ensuring signal strength/bandwidth is sufficient for performance based on
number of devices connected to the Internet and usage needs.</p>

<p>Before contacting your True Fitness representative regarding Internet connectivity, please consult your ISP or IT department.
</p>
<h2>Filtering of Content and Security</h2>
<p>True Fitness Technology, Inc. has no control or responsibility regarding the content and information users may access via the Internet.
Filtering for appropriate content is the responsibility of the facility and equipment owner.
It is recommended that filters and/or firewalls be installed externally to this equipment to regulate
user access of content, and for protection against malicious or inappropriate websites and content.
</p>
<h2>Safety</h2>
<p>Internet usage while exercising can pose risks to safety.   It is recommended that a facility institute guidelines for Internet interaction.
Particular guidelines advising exercisers to disengage Internet interaction during intense exercise is highly recommended.
Specifically for treadmill use, it is recommended that users be advised that interaction with the Internet should occur only at slow walking speeds and care should always
be taken to ensure gait remains stable at the front/center of walking belt.
</p>
<h2>Formatting</h2>
<p>Similar to other tablet and mobile devices with web-browsing capability,
some websites may not function as designed on this device.</p>"

    property string yesText: qsTr("Accept")
    property string noText: qsTr("No")

    property int borderWidth: 950 * browser.hScaleFactor
    property int borderHeight: noButton.height + (20 + 275) * browser.vScaleFactor
    property int textXOffset: 149 * browser.hScaleFactor
    property int textSize: 12 * browser.vScaleFactor

    signal yesClicked()
    signal noClicked()

    width: borderWidth
    height: borderHeight

    BorderImage {   // pop-up dialog background
        id: border

        x: 0
        y: 0
        width: borderWidth
        height: borderHeight
        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152 * browser.vScaleFactor; bottom: 165 * browser.vScaleFactor; left: 145 * browser.hScaleFactor; right: 144  * browser.hScaleFactor}

        Flickable {
            id: scrollText

            clip: true
            flickableDirection: Flickable.VerticalFlick

            anchors {
                fill: parent
                topMargin: 50 * browser.vScaleFactor
                leftMargin: 50 * browser.hScaleFactor
                rightMargin: 100 * browser.hScaleFactor
                bottomMargin: noButton.height + 70 * browser.vScaleFactor
            }

            contentHeight: promptText.height + 30 * browser.vScaleFactor
            contentWidth: promptText.width

            Text {
                id: promptText
                x: textXOffset
                y: 35 * browser.vScaleFactor
                width: scrollText.width - 5 * browser.hScaleFactor
                height: paintedHeight
                //color: "#ffffff"
                text: root.prompt
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * browser.vScaleFactor
                wrapMode: Text.WordWrap
            }
        }

        Text {
            id: scrollForMore
            anchors.top: scrollText.bottom
            anchors.horizontalCenter: scrollText.horizontalCenter
            width: scrollText.width
            horizontalAlignment: Text.AlignHCenter

            text: qsTr("< scroll down for more >")
            visible: !scrollText.atYEnd
        }

        Image {
            id: dataDownArrow
            visible: !scrollText.atYEnd
            source: "graphics/Swipe_Arrows_Right.png"
            rotation: 90
            anchors {
                bottom: parent.bottom; bottomMargin: 240 * browser.vScaleFactor;
                right: parent.right ; rightMargin:15 * browser.hScaleFactor }
        }

        ImageButton {
            id: noButton

            x: 638 * browser.hScaleFactor
            y: 157 * browser.vScaleFactor
            label_y_offset: -65 * browser.vScaleFactor
            label: noText
            label_color: "black"
            smooth: true
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * browser.vScaleFactor
            upimage: browser.graphicsPath + "Small_Stop.png"
            downimage: browser.graphicsPath + "Small_Stop_Down.png"
            onClicked: noClicked()
        }

        ImageButton {
            id: yesButton

            x: 200 * browser.hScaleFactor
            y: 178 * browser.vScaleFactor
            label_y_offset: -65 * browser.vScaleFactor
            label: yesText
            label_color: "black"
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * browser.vScaleFactor
            upimage: browser.graphicsPath + "Small_Start.png"
            downimage: browser.graphicsPath + "Small_Start_Down.png"
            onClicked: yesClicked()
        }
    }
}

